EasyExtend.langlets.p4d.p4dutils.pprinter

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dutils :: Class pprinter |
[hide private]
[frames] | no frames]

# Class pprinter

    object --+
             |
            pprinter

Known Subclasses:
  - xmlutils.xmlprinter
  - , p4dprinter

Instance Methods | [hide private]
__init__(self, tree, stream=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
walker(self, *tree, **kw) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, tree, stream=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Parameters: `tree` - p4d-root node. `stream` - output stream. Overrides: object.__init__